@@ -7,7 +7,6 @@ import shutil
 import sys
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Iterable, cast
-from urllib.parse import urlparse
 
 import platformdirs
 import tomlkit
@@ -16,7 +15,6 @@ from tomlkit.items import Array
 from unearth import Link
 
 from pdm import termui
-from pdm._types import Source
 from pdm.compat import cached_property
 from pdm.exceptions import NoPythonVersion, PdmUsageError, ProjectError
 from pdm.models.backends import BuildBackend, get_backend_by_spec
@@ -43,8 +41,8 @@ from pdm.utils import (
 
 if TYPE_CHECKING:
     from resolvelib.reporters import BaseReporter
-    from rich.status import Status
 
+    from pdm._types import Source, Spinner
     from pdm.core import Core
     from pdm.resolver.providers import BaseProvider
 
@@ -150,10 +148,9 @@ class Project:
         if not self._python:
             self._python = self.resolve_interpreter()
             if self._python.major < 3:
-                deprecation_warning(
-                    "Python 2.7 has reached EOL and PDM will remove the support "
-                    "in version 2.0. Please upgrade your Python to 3.6 or later.",
-                    raise_since="2.0",
+                raise PdmUsageError(
+                    "Python 2.7 has reached EOL and PDM no longer supports it. "
+                    "Please upgrade your Python to 3.6 or later.",
                 )
         return self._python
 
@@ -189,7 +186,7 @@ class Project:
                 if match_version(python):
                     note(
                         f"Inside an active virtualenv [success]{venv_in_env}[/], "
-                        "reuse it."
+                        "reusing it."
                     )
                     return python
             # otherwise, get a venv associated with the project
@@ -351,29 +348,28 @@ class Project:
 
     @property
     def default_source(self) -> Source:
-        """Get the default source of from the pypi setting"""
+        """Get the default source from the pypi setting"""
         return cast(
             "Source",
             {
                 "url": self.config["pypi.url"],
                 "verify_ssl": self.config["pypi.verify_ssl"],
                 "name": "pypi",
+                "username": self.config.get("pypi.username"),
+                "password": self.config.get("pypi.password"),
             },
         )
 
     @property
     def sources(self) -> list[Source]:
         sources = list(self.pyproject.settings.get("source", []))
-        if all(source.get("name") != "pypi" for source in sources):
-            sources.insert(0, self.default_source)
-        expanded_sources: list[Source] = [
-            Source(
-                url=expand_env_vars_in_auth(s["url"]),
-                verify_ssl=s.get("verify_ssl", True),
-                name=s.get("name", urlparse(s["url"]).hostname),
-                type=s.get("type", "index"),
-            )
-            for s in sources
+        if not self.global_config["pypi.ignore_stored_index"]:
+            if all(source.get("name") != "pypi" for source in sources):
+                sources.insert(0, self.default_source)
+            sources.extend(self.global_config.iter_sources())
+        expanded_sources = [
+            cast("Source", {**source, "url": expand_env_vars_in_auth(source["url"])})
+            for source in sources
         ]
         return expanded_sources
 
@@ -454,7 +450,7 @@ class Project:
         self,
         requirements: list[Requirement],
         tracked_names: Iterable[str] | None = None,
-        spinner: Status | termui.DummySpinner | None = None,
+        spinner: Spinner | None = None,
     ) -> BaseReporter:
         """Return the reporter object to construct a resolver.
 
@@ -465,7 +461,10 @@ class Project:
         """
         from pdm.resolver.reporters import SpinnerReporter
 
-        return SpinnerReporter(spinner or termui.DummySpinner(), requirements)
+        if spinner is None:
+            spinner = termui.SilentSpinner("")
+
+        return SpinnerReporter(spinner, requirements)
 
     def get_lock_metadata(self) -> dict[str, Any]:
         content_hash = tomlkit.string("sha256:" + self.pyproject.content_hash("sha256"))
@@ -628,13 +627,15 @@ class Project:
             args = []
         else:
             if not all(c.isdigit() for c in python_spec.split(".")):
-                if Path(python_spec).exists():
+                path = Path(python_spec)
+                if path.exists():
                     python = find_python_in_path(python_spec)
                     if python:
                         yield PythonInfo.from_path(python)
-                python = shutil.which(python_spec)
-                if python:
-                    yield PythonInfo.from_path(python)
+                if len(path.parts) == 1:  # only check for spec with only one part
+                    python = shutil.which(python_spec)
+                    if python:
+                        yield PythonInfo.from_path(python)
                 return
             args = [int(v) for v in python_spec.split(".") if v != ""]
         finder = self._get_python_finder()
